@@ -26,6 +26,10 @@ extensions = [
     'openstackdocstheme',
 ]
 
+# openstackdocstheme options
+repository_name = 'openstack/sushy-tools'
+use_storyboard = True
+
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
 # execute "export SPHINX_DEBUG=1" in your terminal to disable
@@ -37,7 +41,6 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'sushy-tools'
 copyright = u'2016, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
@@ -60,15 +63,15 @@ pygments_style = 'sphinx'
 html_theme = 'openstackdocs'
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = '%sdoc' % project
+htmlhelp_basename = 'sushy-toolsdoc'
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
 latex_documents = [
     ('index',
-     '%s.tex' % project,
-     u'%s Documentation' % project,
+     'doc-sushy-tools.tex',
+     u'Sushy Tools Documentation',
      u'OpenStack Foundation', 'manual'),
 ]
 
